@@ -16,22 +16,20 @@ sub dump {
     my $yamlstring = undef;
     my $modulename = undef;
 
-    eval { 
+    eval {
         require YAML;
         $modulename = 'YAML';
     };
 
     if( $@ ) {
-        # Try to load JSON::Syck
+        # Try to load YAML::Syck
         eval { 
             require YAML::Syck;
             $modulename = 'YAML::Syck';
         };
 
-        if( $@ ) {
-            # YAML::Syck is not installed
-            die ' ***error: Neither "YAML" nor "YAML::Syck" module is installed';
-        }
+        # YAML::Syck is not installed
+        die ' ***error: Neither "YAML" nor "YAML::Syck" module is installed' if $@;
     }
 
     $damneddata = $argvs->damn;
@@ -45,7 +43,7 @@ sub dump {
         $yamlstring = YAML::Dump($damneddata);
 
     } elsif( $modulename eq 'YAML::Syck' ) {
-        # Use JSON::Syck module instead of YAML module.
+        # Use YAML::Syck module instead of YAML module.
         $YAML::Syck::ImplicitTyping  = 1;
         $YAML::Syck::Headless        = 0;
         $YAML::Syck::ImplicitUnicode = 1;
